### Overview

Python 2 and < 3.5 will be or have already reached their end of life. Therefore, new `quandl` releases 
will only support Python versions >= 3.5.

* `quandl` versions less than `3.5.0` will only support Python 2 and Python < 3.5.
* `quandl` versions greater than or equal to `3.5.0` will only support Python >= 3.5

If you're using Python 2 or < 3.5, you'll need to stay at `quandl 3.4.9` or lower.
If you're using Python >= 3.5, its recommended to perform a `pip install --upgrade quandl` to grab the
latest and greatest.

